#!/bin/bash
#
# toBuild.sh -- cron's script to output a list of "build-needed" packages.
#
# Copyright © 2008 Lionel Le Folgoc <mrpouit@ubuntu.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

## reprepro command line
REPREPRO_CLI="reprepro -V --export=normal --delete --basedir /srv/web/medibuntu/repo --confdir /srv/web/medibuntu/conf --dbdir /srv/web/medibuntu/db --logdir /srv/web/medibuntu/log build-needing"
## common architectures
ARCH="i386 amd64"
## available releases
RELEASES=( \
        hardy hardy-staging \
        intrepid intrepid-staging \
        jaunty jaunty-staging \
        karmic karmic-staging \
        lucid lucid-staging \
        )
## corresponding architectures (same array index)
ARCHITECTURES=( \
        "$ARCH powerpc lpia" "$ARCH powerpc lpia" \
        "$ARCH powerpc lpia" "$ARCH powerpc lpia" \
        "$ARCH powerpc lpia" "$ARCH powerpc lpia" \
        "$ARCH lpia" "$ARCH lpia" \
        "$ARCH" "$ARCH" \
        )
## base URL of the repository (will be used to generate the path to dsc files)
BASE_URL="http://packages.medibuntu.org"
## output
DESTDIR="../../public_html"
OUT="$DESTDIR/to_build.html"

# uncomment if you need to clean the destination directory first
#rm -rf $DESTDIR

# let's go
#mkdir $DESTDIR
echo "$(date -R): started."
cat resources/header.html > $OUT

for ((i=0; i<${#RELEASES[*]}; i=i+1)); do
	release=${RELEASES[$i]}
	
	echo "<h2>$release</h2>" >> $OUT
	echo "<ul>" >> $OUT
	# in case all packages of a release are already built, create an invisible <li> to be Xhtml 1.0 Strict valid
	echo "<li style=\"display: none;\"></li>" >> $OUT
	
#	for arch in ${ARCHITECTURES[$i]}; do
	for arch in $ARCH; do
		$REPREPRO_CLI $release $arch | while read line; do
			package=$(echo $line | awk '{print $1}')
			version=$(echo $line | awk '{print $2}')
			dsc_url=$(echo "$BASE_URL/$(echo $line | awk '{print $3}')")
			echo "<li><span class=\"arch\">[$arch]</span> $package (<a href=\"$dsc_url\">dsc</a>)</li>" >> $OUT
		done
	done
	
	echo "</ul>" >> $OUT
	
	# do not forget to empty release for the next release
	release=
done

# last update date
sed "s/@TIMESTAMP@/$(date -R)/" resources/footer.html >> $OUT

# process the blacklisted packages
cat resources/blacklist | while read line; do
	package=$(echo $line | awk '{print $1}')
	arch=$(echo $line | awk '{print $2}')
	sed -i "/<li><span class=\"arch\">\[$arch\]<\/span> $package/d" $OUT
done

# data files
cp -a resources/style.css $DESTDIR/.
cp -a resources/*.png $DESTDIR/.
echo "$(date -R): stopped."

exit 0
